NAME
XML::DOM::YYLex - XML::DOM-specific part of XML::YYLex
SYNOPSIS
use XML::YYLex;
my $parser = XML::YYLex::create_object( $xml_dom_reference );
DESCRIPTION
This module implements the parts of XML::YYLex that are specific to the XML::DOM module. Rather than interacting with this module directly you create instances of it through the factory method create_object defined in XML::YYLex.
Please read the XML::YYLex manpage for further info.
SEE ALSO
XML::YYLex, XML::Sablotron::YYLex, XML::DOM
The XML-YYLex homepage: http://home.debitel.net/user/boesswetter/xml_yylex/